@@ -2,9 +2,5 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 # flake8: noqa
+from . import bisect, build_manager, builds, config, main
 from .evaluators import *
-from . import bisect
-from . import build_manager
-from . import builds
-from . import config
-from . import main
