@@ -4,7 +4,9 @@
 import logging
 import os
 import re
+from pathlib import Path
 from string import Template
+from typing import List, Any
 
 import requests
 from lithium import interestingness
@@ -20,18 +22,17 @@ FLAGS_URL = Template(
 )
 
 
-def _get_rev(binary):
+def _get_rev(binary: Path) -> str:
     """
-    Return either the revision specified in the fuzzmanagerconf
+    Return either the revision specified in the fuzzmanagerconf or tip
     :param binary: Path to build
     """
     rev = "tip"
-    path = "%s.fuzzmanagerconf" % (os.path.splitext(binary)[0],)
-    if os.path.isfile(path):
-        with open(path) as in_fp:
-            for line in in_fp:
-                if line.startswith("product_version"):
-                    rev = line.split("-")[1].strip()
+    path = binary.with_suffix(".fuzzmanagerconf")
+    if path.is_file():
+        for line in path.read_text().splitlines():
+            if line.startswith("product_version"):
+                rev = line.split("-")[1].strip()
 
     return rev
 
@@ -47,9 +48,11 @@ class JSEvaluator(Evaluator):
     Testcase evaluator for SpiderMonkey shells
     """
 
-    def __init__(self, testcase, **kwargs):
+    target = "js"
+
+    def __init__(self, testcase: Path, **kwargs: Any) -> None:
         self.testcase = testcase
-        self.flags = kwargs.get("flags", None)
+        self.flags = kwargs.get("flags", [])
         self.repeat = kwargs.get("repeat", 1)
 
         # JS Shell launch arguments
@@ -68,7 +71,7 @@ class JSEvaluator(Evaluator):
             self._regex = kwargs.get("regex")
 
     @staticmethod
-    def get_valid_flags(rev):
+    def get_valid_flags(rev: str) -> List[str]:
         """
         Extract list of runtime flags available to the current build
         :param rev:
@@ -86,7 +89,7 @@ class JSEvaluator(Evaluator):
 
         return flags
 
-    def verify_build(self, binary, flags):
+    def verify_build(self, binary: Path, flags: List[str]) -> bool:
         """
         Verify that build doesn't crash on start
         :param binary: The path to the target binary
@@ -95,19 +98,21 @@ class JSEvaluator(Evaluator):
         """
         LOG.info("> Verifying build...")
         args = [binary, *flags, "-e", '"quit()"']
-        run_data = interestingness.timed_run.timed_run(args, self.timeout, None)
+        run_data = interestingness.timed_run.timed_run(args, self.timeout)
         if run_data.sta is not interestingness.timed_run.NORMAL:
             LOG.error(">> Build crashed!")
             return False
 
         return True
 
-    def evaluate_testcase(self, build_path):
+    def evaluate_testcase(self, build_path: Path) -> EvaluatorResult:
         """
         Validate build and launch with supplied testcase
         :return: Result of evaluation
         """
-        binary = os.path.join(build_path, "dist", "bin", "js")
+        binary = build_path / "dist" / "bin" / "js"
+        if not binary.is_file():
+            return EvaluatorResult.BUILD_FAILED
         rev = _get_rev(binary)
         all_flags = self.get_valid_flags(rev)
         flags = []
@@ -115,13 +120,19 @@ class JSEvaluator(Evaluator):
             if flag.lstrip("--").split("=")[0] in all_flags:
                 flags.append(flag)
 
-        if os.path.isfile(binary) and self.verify_build(binary, flags):
-            common_args = ["-t", "%s" % self.timeout, binary, *flags, self.testcase]
+        if self.verify_build(binary, flags):
+            common_args = [
+                "-t",
+                f"{self.timeout}",
+                str(binary),
+                *flags,
+                str(self.testcase),
+            ]
 
             try:
                 # Some testcases require setting the cwd to the parent dir
                 previous_path = os.getcwd()
-                os.chdir(os.path.dirname(self.testcase))
+                os.chdir(os.path.dirname(os.path.abspath(self.testcase)))
 
                 for _ in range(self.repeat):
                     LOG.info("> Launching build with testcase...")
